bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 11. Aventiure
___________________________________________________ #### <die Sifrit ze lande mit sinem wibe kom>
| ### o die geste warn alle dan gevarn ### do sprach zuo sim gesinde Sigmvndes barn ### wir svln ovch vns bereiten heim in vnser lant ### liep was ez sinem wibe do ez div vrowe rehte ervant
###### 638 | ### Die fvrsten zuo im giengen vnd sprachen alle dri ### wizzet kvnich Sifrit daz iv immer si ### mit triwen vnser dienst bereit vnz in den tot ### do neig er den herren do man imz so guetlich erbot
###### 639 | ### Wir svln ovch mit iv teilen sprach Giselher daz kint ### lant vnde burge die vnser eigen sint ### swaz vns der witene mac wesen vndertan ### der svlt ir teil vil guoten mit samt Kriemhilde han
###### 640 | ### Der svn Sigmvndes zvo den fvrsten sprach ### do er der herren willen gehorte vnde gesach ### got laziv iwer erbe immer selich sin ### ia tuon ich ir ze rate mit der lieben vrowen min
###### 641 | ### Do sprach div vrowe Kriemhilt habet ir der erben rat ### vmbe Bvrgonden degene ez niht so lihte stat ### si mug ein kvnich gerne fuoren in sin lant ### ia sol si mit mir teilen miner lieben bruoder hant
###### 642 | ### Do sprach der herre Gernot nim dir swen dv wil ### die gerne mit dir riten der vindestu hie vil ### vz drizech hvndert reken nim dir tusent man ### die sin din heimgesinde Kriemhilt senden began
###### 643 | ### nach Hagenen von Trony vnde nach Ortwin ### ob die vnd ir mage Kriemhilde wolden sin ### darvmbe gewan Hagene zorneclichez leben ### er sprach ia mag vns Gvnther nimmer hin gegeben
###### 644 | ### Ander ingesinde lat iv volgen mite ### wan ir wol bekennet der Tronyere site ### wir muozen bi den kvnigen hie ze houe <bestan> ### wir svln ir langen dienen den wir her gevolget han
###### 645 | ### Daz liezen si beliben vnde bereiten sich dan ### ir edel ingesinde vro Kriemhilt zvo ir gewan ### zwo vnd drizech meide vnd funf hvndert man ### Ekehart der graue volgete Kriemhilde dan
###### 646 | ### Vrlop si do namen beidiv riter vnde kneht ### meide vnde vrowen daz was vil michel reht ### gescheiden kvssende wurden si zehant ### si rumten vrolichen des kvnich Gvnthers lant
###### 647 | ### Do beleiten si ir mage verre vf den wegen ### man hiez in allenthalben ir nahtselde legen ### swa siz gerne namen durch der kvnige lant ### boten wurden balde Sigmvnde dan gesant [27a]
###### 648 | ### daz er wizzen solde vnd frov Sigelint ### daz sin svn koeme vnde vrov voten kint ### Kiemhilt div vil schoene von Wormez vber Rin ### do kvnden in div mere nimmer lieber gesin
###### 649 | ### Wol mich sprach do Sigmvnt daz ich gelebet han ### daz div schoene Chriemhilt sol hie gekronet gan ### des muosen wol getiwert sin div erbe min ### min svn Sifrit sol hie selbe kvnich sin
###### 650 | ### Do gap div vrowe Siglint manigen samit rot ### silber vnde golt swere was ir botenbrot ### si vrovte sich der mere div si do vernam ### sich chleidete ir gesinde mit flize wol als in gezam
###### 651 | ### Man seite wer da koeme mit im in daz lant ### do hiez si gesidele rihten sa zehant ### daz zuo er gekronet vor vrivnden solde gan ### do riten in engegene des kvnich Sigmundes man
###### 652 | ### Ist ieman baz enphangen dest mir vnbekant ### danne die helde in Sigmvndes lant ### Siglint div schoene Kriemhilde gegen reit ### mit maniger schoenen frovwen vn– ritteren gemeit
###### 653 | ### in einer tageweide da man die geste sach ### die kvnden vnd die vremdem liten vngemach ### vnze si kornen zeiner burge wit ### div was geheizen Santen da si krone truogen sit
###### 654 | ### Mit lachendem mvnde Siglint vnd Sigmvnt ### kvsten Kriemhilde durch liebe manige stvnt ### vnd ovch Sifriden in was ir leit benomen ### allez ir gesinde was in grozlichen willekomen
###### 655 | ### Man bat die geste bringen fur Sigmvndes sal ### die schoenen ivnchvrowen huop man da zetal ### nider von den moeren da was manich man ### der den schoenen wiben mit flize dienen began
###### 656 | ### Dos in ir grozen eren sazen vnd heten genuoch ### waz goltvarwer gern ir ingesinde truoch ### borten vnd edel gesteine verwiert wol darin ### sus pflach vlizeclichen ir div edel kvnigin
###### 657 | ### Do sprach vor sinen frivnden der herre Sigmnvnt ### den Sifrides magen tuon ich allen kvnt ### er sol vor disen reken mine krone tragen ### div mere horten gerne die von Niderlanden sagen
###### 658 | ### Er bevalch im sin krone gerihte vnde lant ### sit was er ir herre die er ze rehte vant ### vnd dar er rihten solde daz wart also getan ### daz man sere vorhte der schoenen Kriemhilde man
###### 659 | ### In disen grozen eren lebter daz ist war ### vnd rihte ovch vnder krone an daz zehende iar ### daz div schoene vrowe einen svn gewan ### daz was des kvniges magen nach willen wol ergan
###### 660 | ### Den ilte man do tovfen vnd gap im einen namen ### Gvnther nach sinem ovheim des dorft er sich niht schamen ### geriet er nach den magen daz wer im wol ergan [27b] ### do zoch man in mit flize des was von schvlden getan
###### 661 | ### In den selben ziten starp vro Siglint ### do nam den gewalt mit alle der edelen voten kint ### der so riken vrowen ob landen wol gezam ### daz klageten genuoge do si der tot von in genam
###### 662 | ### Nv hete ovch dort die Rine so wir hoeren sagen ### bi Gvnther dem riken einen svn getragen ### Pruonhilt div schoene in Burgonden lant ### durch des heldes liebe wart er Sifrit genant
###### 663 | ### Mere zallen ziten wart so vil geseit ### wie rehte lobelichen die reken wol gemeit ### lebeten zallen stvnden in Sigmundes lant ### alsam tet ovch Gvnther mit sinen magen vzerkant
###### 664 | ### Daz lant der Niblvnge Sifride diente hie ### richer siner mage wart neheiner nie ### vnd Schilbundes reken vnd ir beider guot ### des truoch der kuene Syfrit deste hoeher sinen muot
###### 665 | ### Hort den aller meisten den ie helt gewan ### ane die es pflagen hete der kvene man ### den er vor eime berge mit siner hende erstreit ### darvmb er sluoch ce tode manigen riter gemeit
###### 666 | ### Er hete den wunsch der eren vnde were des niht geschehen ### so muese man von schvlden dem edelen reken iehen ### daz er were der beste der ie vf ors gesaz ### man vorhte sine sterke vnd tet vil billichen daz

<<< Übersicht <<< vorige Seite nächste Seite >>>